==> haskell-heaps-0.4-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heaps.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heaps
version:              0.4
visibility:           public
id:                   heaps-0.4-AUw80NJWncIBuzL6kLFOt
key:                  heaps-0.4-AUw80NJWncIBuzL6kLFOt
license:              BSD-3-Clause
copyright:            (c) 2010-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/heaps/
synopsis:             Asymptotically optimal Brodal/Okasaki heaps.
description:
    Asymptotically optimal Brodal\/Okasaki bootstrapped skew-binomial heaps from the paper <http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.48.973 "Optimal Purely Functional Priority Queues">, extended with a '\''Foldable'\'' interface.

category:             Data Structures
abi:                  b879f505280987264d80ab21fb5cd5cf
exposed:              True
exposed-modules:      Data.Heap
import-dirs:          /usr/lib/ghc-9.0.1/site-local/heaps-0.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/heaps-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/heaps-0.4
hs-libraries:         HSheaps-0.4-AUw80NJWncIBuzL6kLFOt
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-heaps/html/heaps.haddock
haddock-html:         /usr/share/doc/haskell-heaps/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-heaps-0.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heaps.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heaps
version:              0.4
visibility:           public
id:                   heaps-0.4-2Igl4eZIICN6j5rk1LQb6G
key:                  heaps-0.4-2Igl4eZIICN6j5rk1LQb6G
license:              BSD-3-Clause
copyright:            (c) 2010-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/heaps/
synopsis:             Asymptotically optimal Brodal/Okasaki heaps.
description:
    Asymptotically optimal Brodal\/Okasaki bootstrapped skew-binomial heaps from the paper <http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.48.973 "Optimal Purely Functional Priority Queues">, extended with a '\''Foldable'\'' interface.

category:             Data Structures
abi:                  651ca050748fe4ab03c8ccc8c9d93ec7
exposed:              True
exposed-modules:      Data.Heap
import-dirs:          /usr/lib/ghc-9.0.2/site-local/heaps-0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/heaps-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/heaps-0.4
hs-libraries:         HSheaps-0.4-2Igl4eZIICN6j5rk1LQb6G
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-heaps/html/heaps.haddock
haddock-html:         /usr/share/doc/haskell-heaps/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
